@@ -4,27 +4,21 @@ import boto3
 import datetime
 from boto3.dynamodb.conditions import Key
 
-client = boto3.client('dynamodb')
-
 
 class DynamoDb:
-    __tags = []
-    __table_name = 'acl-run-monitoring'
-
     __CREATING_TABLE_TIMEOUT_IN_MINUTES = 5
 
-    def __init__(self, options=None):
-        if options:
-            if options.get('tags'):
-                self.__tags = options['tags']
-            if options.get('table_name'):
-                self.__table_name = options['table_name']
+    def __init__(self, options={}):
+        self.__region = options['region']
+        self.__dynamo_db_client = boto3.client('dynamodb', region_name=self.__region)
+        self.__tags = options.get('tags', [])
+        self.__table_name = options.get('table_name', 'acl-run-monitoring')
         if not self.__does_table_exist():
             self.__create_table()
             self.wait_for_table_creating()
 
     def __create_table(self):
-        client.create_table(
+        self.__dynamo_db_client.create_table(
             AttributeDefinitions=[
                 {
                     'AttributeName': 'id',
@@ -45,14 +39,14 @@ class DynamoDb:
 
     def __does_table_exist(self):
         try:
-            client.describe_table(TableName=self.__table_name)
+            self.__dynamo_db_client.describe_table(TableName=self.__table_name)
             return True
-        except client.exceptions.ResourceNotFoundException:
+        except self.__dynamo_db_client.exceptions.ResourceNotFoundException:
             return False
 
     def wait_for_table_creating(self):
         start_time = datetime.datetime.now()
-        status = client.describe_table(TableName=self.__table_name)['Table']['TableStatus']
+        status = self.__dynamo_db_client.describe_table(TableName=self.__table_name)['Table']['TableStatus']
         while status != 'ACTIVE':
             now_time = datetime.datetime.now()
             diff = now_time - start_time
@@ -60,10 +54,10 @@ class DynamoDb:
             if diff_minutes > self.__CREATING_TABLE_TIMEOUT_IN_MINUTES:
                 raise Exception('Table creation timeout')
             time.sleep(10)
-            status = client.describe_table(TableName=self.__table_name)['Table']['TableStatus']
+            status = self.__dynamo_db_client.describe_table(TableName=self.__table_name)['Table']['TableStatus']
 
     def put_entry(self, request_payload):
-        response = client.put_item(
+        response = self.__dynamo_db_client.put_item(
             TableName=self.__table_name,
             Item={
                 'id': {
@@ -84,7 +78,7 @@ class DynamoDb:
         return response
 
     def update_status(self, entry_id, status):
-        client.update_item(
+        self.__dynamo_db_client.update_item(
             TableName=self.__table_name,
             Key={
                 'id': {
@@ -106,7 +100,7 @@ class DynamoDb:
         )
 
     def add_ecs_task_logs(self, entry_id, ecs_task_logs):
-        client.update_item(
+        self.__dynamo_db_client.update_item(
             TableName=self.__table_name,
             Key={
                 'id': {
@@ -128,7 +122,7 @@ class DynamoDb:
         )
 
     def add_reason(self, entry_id, reason):
-        client.update_item(
+        self.__dynamo_db_client.update_item(
             TableName=self.__table_name,
             Key={
                 'id': {
@@ -150,7 +144,7 @@ class DynamoDb:
         )
 
     def add_task_arn(self, entry_id, ecs_cluster_name, task_arn):
-        client.update_item(
+        self.__dynamo_db_client.update_item(
             TableName=self.__table_name,
             Key={
                 'id': {
@@ -172,7 +166,7 @@ class DynamoDb:
         )
 
     def update_state(self, entry_id, state):
-        client.update_item(
+        self.__dynamo_db_client.update_item(
             TableName=self.__table_name,
             Key={
                 'id': {
@@ -194,7 +188,7 @@ class DynamoDb:
         )
 
     def get_entry(self, entry_id):
-        table = boto3.resource('dynamodb').Table(self.__table_name)
+        table = boto3.resource('dynamodb', region_name=self.__region).Table(self.__table_name)
         response = table.query(
             KeyConditionExpression=Key('id').eq(entry_id)
         )
@@ -205,4 +199,4 @@ class DynamoDb:
         return response['Items'][0]
 
     def delete_table(self):
-        client.delete_table(TableName=self.__table_name)
+        self.__dynamo_db_client.delete_table(TableName=self.__table_name)
