@@ -16,6 +16,7 @@ from .exception.InstanceDeployingTimeoutException import InstanceDeployingTimeou
 
 
 class ContainerLauncher:
+    __DEFAULT_AWS_REGION = 'us-east-1'
     __ASG_DRAINING_TIMEOUT_IN_MINUTES = 5
     __INSTANCE_TERMINATION_TIMEOUT_IN_MINUTES = 5
     __SPOT_INSTANCE_DEPLOYING_TIMEOUT_IN_MINUTES = 10
@@ -31,7 +32,7 @@ class ContainerLauncher:
         'arn:aws:iam::aws:policy/service-role/AmazonEC2ContainerServiceforEC2Role'
     ]
 
-    def __init__(self, options=None):
+    def __init__(self, options={}):
         self.__options = None
         self.__name_prefix = 'acl'
         self.__tags = []
@@ -52,30 +53,23 @@ class ContainerLauncher:
 
         self.__options = options if options else {}
 
-        monitoring_table_tags = self.__get_tags(self.__options.get('monitoring_table_tags'))
-        self.__dynamodb = DynamoDb({
-            'tags': monitoring_table_tags
-        })
+        self.__region = options.get('region', os.environ.get('AWS_DEFAULT_REGION',
+                                                             os.environ.get('AWS_REGION', self.__DEFAULT_AWS_REGION)))
 
-        if options is not None and options.get('region') is not None:
-            region = options['region']
-            self.clients = {
-                'ecs': boto3.client('ecs', region_name=region),
-                'autoscaling': boto3.client('autoscaling', region_name=region),
-                'cloudwatch': boto3.client('cloudwatch', region_name=region),
-                'iam': boto3.client('iam', region_name=region),
-                'ec2': boto3.client('ec2', region_name=region)
-            }
-            self.__region = region
-        else:
-            self.clients = {
-                'ecs': boto3.client('ecs'),
-                'autoscaling': boto3.client('autoscaling'),
-                'cloudwatch': boto3.client('cloudwatch'),
-                'iam': boto3.client('iam'),
-                'ec2': boto3.client('ec2')
-            }
-            self.__region = self.clients['ecs'].meta.region_name
+        self.clients = {
+            'ecs': boto3.client('ecs', region_name=self.__region),
+            'autoscaling': boto3.client('autoscaling', region_name=self.__region),
+            'cloudwatch': boto3.client('cloudwatch', region_name=self.__region),
+            'iam': boto3.client('iam', region_name=self.__region),
+            'ec2': boto3.client('ec2', region_name=self.__region)
+        }
+
+        monitoring_table_tags = self.__get_tags(self.__options.get('monitoring_table_tags'))
+
+        self.__dynamodb = DynamoDb({
+            'tags': monitoring_table_tags,
+            'region': self.__region
+        })
 
         if self.__options.get('logger'):
             self.logger = self.__options['logger']
@@ -348,7 +342,9 @@ class ContainerLauncher:
             self.__dynamodb.update_status(entry_id, RunStatus.FAILED.name)
             return {
                 'status': RunStatus.FAILED.name,
-                'error': error_message
+                'error': {
+                    'message': error_message
+                }
             }
 
         return {
